# Contributing to pygount

For more information on building pygount and contributing to it, read the
[respective chapter of the documentation](https://pygount.readthedocs.io/en/latest/contributing/).
